@@ -16,9 +16,8 @@
  * 
  */
 
-
-#ifndef _BMC_CONFIG_SOL_CONF_SECTION_H_
-#define _BMC_CONFIG_SOL_CONF_SECTION_H_
+#ifndef BMC_CONFIG_SOL_CONF_SECTION_H
+#define BMC_CONFIG_SOL_CONF_SECTION_H
 
 #include "bmc-config.h"
 #include "bmc-config-sections.h"
@@ -26,4 +25,4 @@
 struct config_section * bmc_config_sol_conf_section_get (bmc_config_state_data_t *state_data,
 							 unsigned int config_flags,
 							 int channel_index);
-#endif /* _BMC_CONFIG_SOL_CONF_SECTION_H_ */
+#endif /* BMC_CONFIG_SOL_CONF_SECTION_H */
