@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _CONFIG_TOOL_PARSE_H_
-#define _CONFIG_TOOL_PARSE_H_
+#ifndef CONFIG_TOOL_PARSE_H
+#define CONFIG_TOOL_PARSE_H
 
 #include "config-tool-common.h"
 #include "pstdout.h"
@@ -27,4 +27,4 @@ config_err_t config_parse (pstdout_state_t pstate,
                            struct config_arguments *cmd_args,
                            FILE *fp);
 
-#endif /* _CONFIG_TOOL_PARSE_H_ */
+#endif /* CONFIG_TOOL_PARSE_H */
