@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H
-#define _IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H
+#ifndef IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H
+#define IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -198,4 +198,4 @@ FIID Template: tmpl_fru_oem_record
 }
 #endif
 
-#endif  /* _IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H */
+#endif /* IPMI_FRU_INFORMATION_RECORD_FORMAT_TEMPLATES_H */
