@@ -24,8 +24,8 @@
  *  with Ipmimonitoring.  If not, see <http://www.gnu.org/licenses/>.
 \*****************************************************************************/
 
-#ifndef _IPMI_MONITORING_OFFSETS_H
-#define _IPMI_MONITORING_OFFSETS_H
+#ifndef IPMI_MONITORING_OFFSETS_H
+#define IPMI_MONITORING_OFFSETS_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -535,4 +535,4 @@ enum ipmi_monitoring_event_offset_fru_state
 }
 #endif
 
-#endif /* _IPMI_MONITORING_OFFSETS_H */
+#endif /* IPMI_MONITORING_OFFSETS_H */
