@@ -65,7 +65,7 @@ _sel_cleanup (ipmi_monitoring_ctx_t c)
   assert (c);
   assert (c->magic == IPMI_MONITORING_MAGIC);
 
-  ipmi_sel_parse_ctx_destroy (c->sel_parse_ctx);
+  ipmi_sel_ctx_destroy (c->sel_parse_ctx);
   c->sel_parse_ctx = NULL;
 }
 
@@ -75,12 +75,12 @@ ipmi_monitoring_sel_init (ipmi_monitoring_ctx_t c)
   assert (c);
   assert (c->magic == IPMI_MONITORING_MAGIC);
   assert (c->ipmi_ctx);
-  assert (c->sdr_cache_ctx);
+  assert (c->sdr_ctx);
   assert (!c->sel_parse_ctx);
 
-  if (!(c->sel_parse_ctx = ipmi_sel_parse_ctx_create (c->ipmi_ctx, c->sdr_cache_ctx)))
+  if (!(c->sel_parse_ctx = ipmi_sel_ctx_create (c->ipmi_ctx, c->sdr_ctx)))
     {
-      IPMI_MONITORING_DEBUG (("ipmi_sel_parse_ctx_create: %s", strerror (errno)));
+      IPMI_MONITORING_DEBUG (("ipmi_sel_ctx_create: %s", strerror (errno)));
       c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
       goto cleanup;
     }
@@ -259,16 +259,16 @@ _sel_parse_ctx_error_convert (ipmi_monitoring_ctx_t c)
   assert (c->ipmi_ctx);
   assert (c->sel_parse_ctx);
 
-  errnum = ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx);
+  errnum = ipmi_sel_ctx_errnum (c->sel_parse_ctx);
 
   /* if callback error - assume we set as needed */
-  if (errnum != IPMI_SEL_PARSE_ERR_CALLBACK_ERROR)
+  if (errnum != IPMI_SEL_ERR_CALLBACK_ERROR)
     {
-      if (errnum == IPMI_SEL_PARSE_ERR_IPMI_ERROR)
+      if (errnum == IPMI_SEL_ERR_IPMI_ERROR)
         c->errnum = IPMI_MONITORING_ERR_IPMI_ERROR;
-      else if (errnum == IPMI_SEL_PARSE_ERR_OUT_OF_MEMORY)
+      else if (errnum == IPMI_SEL_ERR_OUT_OF_MEMORY)
         c->errnum = IPMI_MONITORING_ERR_OUT_OF_MEMORY;
-      else if (errnum == IPMI_SEL_PARSE_ERR_SYSTEM_ERROR)
+      else if (errnum == IPMI_SEL_ERR_SYSTEM_ERROR)
         c->errnum = IPMI_MONITORING_ERR_SYSTEM_ERROR;
       else
         c->errnum = IPMI_MONITORING_ERR_INTERNAL_ERROR;
@@ -277,7 +277,8 @@ _sel_parse_ctx_error_convert (ipmi_monitoring_ctx_t c)
 
 static int
 _ipmi_monitoring_sel_parse_system_event_record (ipmi_monitoring_ctx_t c,
-                                                struct ipmi_monitoring_sel_record *s)
+                                                struct ipmi_monitoring_sel_record *s,
+						unsigned int sel_flags)
 {
   uint32_t timestamp;
   uint8_t sel_sensor_type;
@@ -290,25 +291,32 @@ _ipmi_monitoring_sel_parse_system_event_record (ipmi_monitoring_ctx_t c,
   uint8_t event_data3;
   char event_offset_string[IPMI_MONITORING_SEL_EVENT_OFFSET_STRING_MAX + 1];
   int sensor_type;
+  unsigned int sel_string_flags;
   int ret;
 
   assert (c);
   assert (c->magic == IPMI_MONITORING_MAGIC);
   assert (s);
 
-  if (ipmi_sel_parse_read_timestamp (c->sel_parse_ctx, &timestamp) < 0)
+  if (ipmi_sel_parse_read_timestamp (c->sel_parse_ctx,
+				     NULL,
+				     0,
+				     &timestamp) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_timestamp: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->timestamp = timestamp;
 
-  if (ipmi_sel_parse_read_sensor_type (c->sel_parse_ctx, &sel_sensor_type) < 0)
+  if (ipmi_sel_parse_read_sensor_type (c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &sel_sensor_type) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_sensor_type: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -318,20 +326,26 @@ _ipmi_monitoring_sel_parse_system_event_record (ipmi_monitoring_ctx_t c,
 
   s->sensor_type = sensor_type;
 
-  if (ipmi_sel_parse_read_sensor_number (c->sel_parse_ctx, &sensor_number) < 0)
+  if (ipmi_sel_parse_read_sensor_number (c->sel_parse_ctx,
+					 NULL,
+					 0,
+					 &sensor_number) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_sensor_number: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
 
   s->sensor_number = sensor_number;
   
-  if (ipmi_sel_parse_read_event_direction (c->sel_parse_ctx, &event_direction) < 0)
+  if (ipmi_sel_parse_read_event_direction (c->sel_parse_ctx,
+					   NULL,
+					   0,
+					   &event_direction) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_direction: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -341,19 +355,25 @@ _ipmi_monitoring_sel_parse_system_event_record (ipmi_monitoring_ctx_t c,
   else
     s->event_direction = IPMI_MONITORING_SEL_EVENT_DIRECTION_DEASSERTION;
       
-  if (ipmi_sel_parse_read_event_data1_offset_from_event_reading_type_code (c->sel_parse_ctx, &event_offset) < 0)
+  if (ipmi_sel_parse_read_event_data1_offset_from_event_reading_type_code (c->sel_parse_ctx,
+									   NULL,
+									   0,
+									   &event_offset) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_data1_offset_from_event_reading_type_code: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->event_offset = event_offset;
 
-  if (ipmi_sel_parse_read_event_type_code (c->sel_parse_ctx, &event_type_code) < 0)
+  if (ipmi_sel_parse_read_event_type_code (c->sel_parse_ctx,
+					   NULL,
+					   0,
+					   &event_type_code) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_type_code: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -364,55 +384,74 @@ _ipmi_monitoring_sel_parse_system_event_record (ipmi_monitoring_ctx_t c,
                                                       sel_sensor_type)) < 0)
     return (-1);
 
-  if (ipmi_sel_parse_read_event_data1 (c->sel_parse_ctx, &event_data1) < 0)
+  if (ipmi_sel_parse_read_event_data1 (c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &event_data1) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_data1: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->event_data1 = event_data1;
 
-  if (ipmi_sel_parse_read_event_data2 (c->sel_parse_ctx, &event_data2) < 0)
+  if (ipmi_sel_parse_read_event_data2 (c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &event_data2) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_data2: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->event_data2 = event_data2;
 
-  if (ipmi_sel_parse_read_event_data3 (c->sel_parse_ctx, &event_data3) < 0)
+  if (ipmi_sel_parse_read_event_data3 (c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &event_data3) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_event_data3: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->event_data3 = event_data3;
 
+  sel_string_flags = IPMI_SEL_STRING_FLAGS_IGNORE_UNAVAILABLE_FIELD | IPMI_SEL_STRING_FLAGS_OUTPUT_NOT_AVAILABLE;
+  if (sel_flags & IPMI_MONITORING_SEL_FLAGS_ENTITY_SENSOR_NAMES)
+    sel_string_flags |= IPMI_SEL_STRING_FLAGS_ENTITY_SENSOR_NAMES;
+  
   if (ipmi_sel_parse_read_record_string (c->sel_parse_ctx,
                                          "%s",
+					 NULL,
+					 0,
                                          s->sensor_name,
                                          IPMI_MONITORING_MAX_SENSOR_NAME_LENGTH,
-                                         IPMI_SEL_PARSE_STRING_FLAGS_IGNORE_UNAVAILABLE_FIELD | IPMI_SEL_PARSE_STRING_FLAGS_OUTPUT_NOT_AVAILABLE) < 0)
+                                         sel_string_flags) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_string: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
 
   memset (event_offset_string, '\0', IPMI_MONITORING_SEL_EVENT_OFFSET_STRING_MAX + 1);
 
+  sel_string_flags = IPMI_SEL_STRING_FLAGS_IGNORE_UNAVAILABLE_FIELD | IPMI_SEL_STRING_FLAGS_OUTPUT_NOT_AVAILABLE;
+
   if ((ret = ipmi_sel_parse_read_record_string (c->sel_parse_ctx,
                                                 "%e",
+						NULL,
+						0,
                                                 event_offset_string,
                                                 IPMI_MONITORING_SEL_EVENT_OFFSET_STRING_MAX,
-                                                IPMI_SEL_PARSE_STRING_FLAGS_IGNORE_UNAVAILABLE_FIELD | IPMI_SEL_PARSE_STRING_FLAGS_OUTPUT_NOT_AVAILABLE)) < 0)
+						sel_string_flags)) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_string: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -452,30 +491,38 @@ _ipmi_monitoring_sel_parse_timestamped_oem_record (ipmi_monitoring_ctx_t c,
   assert (c->magic == IPMI_MONITORING_MAGIC);
   assert (s);
 
-  if (ipmi_sel_parse_read_timestamp (c->sel_parse_ctx, &timestamp) < 0)
+  if (ipmi_sel_parse_read_timestamp (c->sel_parse_ctx,
+				     NULL,
+				     0,
+				     &timestamp) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_timestamp: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->timestamp = timestamp;
   
-  if (ipmi_sel_parse_read_manufacturer_id (c->sel_parse_ctx, &manufacturer_id) < 0)
+  if (ipmi_sel_parse_read_manufacturer_id (c->sel_parse_ctx,
+					   NULL,
+					   0,
+					   &manufacturer_id) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_manufacturer_id: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
   s->manufacturer_id = manufacturer_id;
 
   if ((ret = ipmi_sel_parse_read_oem (c->sel_parse_ctx,
+				      NULL,
+				      0,
                                       s->oem_data,
                                       IPMI_MONITORING_OEM_DATA_MAX)) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_oem: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -495,11 +542,13 @@ _ipmi_monitoring_sel_parse_non_timestamped_oem_record (ipmi_monitoring_ctx_t c,
   assert (s);
 
   if ((ret = ipmi_sel_parse_read_oem (c->sel_parse_ctx,
+				      NULL,
+				      0,
                                       s->oem_data,
                                       IPMI_MONITORING_OEM_DATA_MAX)) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_oem: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       return (-1);
     }
@@ -537,23 +586,29 @@ _store_sel_record (ipmi_monitoring_ctx_t c, unsigned int sel_flags)
                                                     IPMI_SEL_RECORD_MAX_RECORD_LENGTH)) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       goto cleanup;
     }
   
-  if (ipmi_sel_parse_read_record_id (c->sel_parse_ctx, &record_id) < 0)
+  if (ipmi_sel_parse_read_record_id (c->sel_parse_ctx,
+				     NULL,
+				     0,
+				     &record_id) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_id: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       goto cleanup;
     }
 
-  if (ipmi_sel_parse_read_record_type (c->sel_parse_ctx, &record_type) < 0)
+  if (ipmi_sel_parse_read_record_type (c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &record_type) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_id: %s",
-                              ipmi_sel_parse_ctx_errnum (c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (c);
       goto cleanup;
     }
@@ -598,7 +653,7 @@ _store_sel_record (ipmi_monitoring_ctx_t c, unsigned int sel_flags)
     {
       s->record_type_class = IPMI_MONITORING_SEL_RECORD_TYPE_CLASS_SYSTEM_EVENT_RECORD;
 
-      if (_ipmi_monitoring_sel_parse_system_event_record (c, s) < 0)
+      if (_ipmi_monitoring_sel_parse_system_event_record (c, s, sel_flags) < 0)
         goto cleanup;
     }
   else if (record_type_class == IPMI_SEL_RECORD_TYPE_CLASS_TIMESTAMPED_OEM_RECORD)
@@ -650,7 +705,7 @@ _store_sel_record (ipmi_monitoring_ctx_t c, unsigned int sel_flags)
 }
 
 static int
-_ipmi_monitoring_sel_parse_record_id (ipmi_sel_parse_ctx_t ctx, void *callback_data)
+_ipmi_monitoring_sel_parse_record_id (ipmi_sel_ctx_t ctx, void *callback_data)
 {
   struct sel_parse_data *spd;
 
@@ -667,7 +722,7 @@ _ipmi_monitoring_sel_parse_record_id (ipmi_sel_parse_ctx_t ctx, void *callback_d
 }
 
 static int
-_ipmi_monitoring_sel_parse_sensor_types (ipmi_sel_parse_ctx_t ctx, void *callback_data)
+_ipmi_monitoring_sel_parse_sensor_types (ipmi_sel_ctx_t ctx, void *callback_data)
 {
   struct sel_parse_data *spd;
   uint8_t record_type;
@@ -678,10 +733,13 @@ _ipmi_monitoring_sel_parse_sensor_types (ipmi_sel_parse_ctx_t ctx, void *callbac
 
   spd = (struct sel_parse_data *)callback_data;
 
-  if (ipmi_sel_parse_read_record_type (spd->c->sel_parse_ctx, &record_type) < 0)
+  if (ipmi_sel_parse_read_record_type (spd->c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &record_type) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_id: %s",
-                              ipmi_sel_parse_ctx_errnum (spd->c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (spd->c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (spd->c);
       return (-1);
     }
@@ -706,10 +764,13 @@ _ipmi_monitoring_sel_parse_sensor_types (ipmi_sel_parse_ctx_t ctx, void *callbac
       int sensor_type;
       int found = 0;
 
-      if (ipmi_sel_parse_read_sensor_type (spd->c->sel_parse_ctx, &sel_sensor_type) < 0)
+      if (ipmi_sel_parse_read_sensor_type (spd->c->sel_parse_ctx,
+					   NULL,
+					   0,
+					   &sel_sensor_type) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_sensor_type: %s",
-                                  ipmi_sel_parse_ctx_errnum (spd->c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errnum (spd->c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (spd->c);
           return (-1);
         }
@@ -737,7 +798,7 @@ _ipmi_monitoring_sel_parse_sensor_types (ipmi_sel_parse_ctx_t ctx, void *callbac
 }
 
 static int
-_ipmi_monitoring_sel_parse_date_range (ipmi_sel_parse_ctx_t ctx, void *callback_data)
+_ipmi_monitoring_sel_parse_date_range (ipmi_sel_ctx_t ctx, void *callback_data)
 {
   struct sel_parse_data *spd;
   uint8_t record_type;
@@ -748,10 +809,13 @@ _ipmi_monitoring_sel_parse_date_range (ipmi_sel_parse_ctx_t ctx, void *callback_
 
   spd = (struct sel_parse_data *)callback_data;
 
-  if (ipmi_sel_parse_read_record_type (spd->c->sel_parse_ctx, &record_type) < 0)
+  if (ipmi_sel_parse_read_record_type (spd->c->sel_parse_ctx,
+				       NULL,
+				       0,
+				       &record_type) < 0)
     {
       IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_record_id: %s",
-                              ipmi_sel_parse_ctx_errnum (spd->c->sel_parse_ctx)));
+                              ipmi_sel_ctx_errnum (spd->c->sel_parse_ctx)));
       _sel_parse_ctx_error_convert (spd->c);
       return (-1);
     }
@@ -774,10 +838,13 @@ _ipmi_monitoring_sel_parse_date_range (ipmi_sel_parse_ctx_t ctx, void *callback_
     {
       uint32_t timestamp;
 
-      if (ipmi_sel_parse_read_timestamp (spd->c->sel_parse_ctx, &timestamp) < 0)
+      if (ipmi_sel_parse_read_timestamp (spd->c->sel_parse_ctx,
+					 NULL,
+					 0,
+					 &timestamp) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse_read_timestamp: %s",
-                                  ipmi_sel_parse_ctx_errnum (spd->c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errnum (spd->c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (spd->c);
           return (-1);
         }
@@ -841,7 +908,7 @@ ipmi_monitoring_get_sel (ipmi_monitoring_ctx_t c,
                                      &spd) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse: %s",
-                                  ipmi_sel_parse_ctx_errormsg (c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errormsg (c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (c);
           goto cleanup;
         }
@@ -859,7 +926,7 @@ ipmi_monitoring_get_sel (ipmi_monitoring_ctx_t c,
                           &spd) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse: %s",
-                                  ipmi_sel_parse_ctx_errormsg (c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errormsg (c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (c);
           goto cleanup;
         }
@@ -877,7 +944,7 @@ ipmi_monitoring_get_sel (ipmi_monitoring_ctx_t c,
                           &spd) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse: %s",
-                                  ipmi_sel_parse_ctx_errormsg (c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errormsg (c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (c);
           goto cleanup;
         }
@@ -891,7 +958,7 @@ ipmi_monitoring_get_sel (ipmi_monitoring_ctx_t c,
                           &spd) < 0)
         {
           IPMI_MONITORING_DEBUG (("ipmi_sel_parse: %s",
-                                  ipmi_sel_parse_ctx_errormsg (c->sel_parse_ctx)));
+                                  ipmi_sel_ctx_errormsg (c->sel_parse_ctx)));
           _sel_parse_ctx_error_convert (c);
           goto cleanup;
         }
